@@ -6,13 +6,14 @@
 """
 
 import os
-from random import randnit
+from random import randint
 
 import numpy as np
 from numpy import asarray
 from statistics import mean
 from vidstab import VidStab
 from sometime import Sometime
+import moviepy.video.fx.all as vfx
 from moviepy.editor import AudioFileClip, VideoFileClip, TextClip, CompositeVideoClip, concatenate_videoclips
 
 def strip_filename(path):
@@ -27,6 +28,10 @@ class Amphi:
 
         self.height = int((self.width * 9 / 16))
         self.dimension = self.width, self.height
+        
+        self.max = max
+        if not isinstance(max, int):
+            self.max = 5
 
         self.clips = []
         self.audios = {}
@@ -60,12 +65,13 @@ class Amphi:
     
     def video(self, name):
         self.video_clip = self.videos.get(name, None)
+        return self
     
     def highlight(self):
         # https://www.pyimagesearch.com/2014/09/15/python-compare-two-images/
         if self.video_clip is not None:
             max_duration = round(self.video_clip.duration)
-            if max_duration > max: 
+            if max_duration > self.max: 
                 previous = None
                 temp_highlights = {}
                 for index in range(max_duration):
@@ -83,7 +89,7 @@ class Amphi:
                 if len(highlights) > 0:
                     indices = list(highlights.keys())
                     index = indices[randint(0, (len(indices)-1))]
-                    if index <= (max_duration - max):
+                    if index <= (max_duration - self.max):
                         mse = highlights.get(index)
                         self.video_clip = self.video_clip.subclip(index)
         return self
@@ -101,9 +107,9 @@ class Amphi:
         if self.video_clip is not None:
             if end is None:
                 end = self.video_clip.duration
-            duration = end - start
-            if duration > max:
-                max_duration = min((start+max), self.video_clip.duration)
+            duration = int((end - start))
+            if duration > self.max:
+                max_duration = min((start+self.max), self.video_clip.duration)
                 end = start + max_duration
             self.video_clip = self.video_clip.subclip(start, end)
         return self
@@ -166,8 +172,9 @@ class Amphi:
     def fadein(self, duration):
         if self.video_clip is not None:
             try:
-                if duration > 0:
-                    self.video_clip.fadein(float(duration))
+                if isinstance(duration, int) or isinstance(duration, float):
+                    if 0 < duration <= 5:
+                        self.video_clip - self.video_clip.fadein(float(duration))
             except:
                 pass
         return self
@@ -175,12 +182,44 @@ class Amphi:
     def fadeout(self, duration):
         if self.video_clip is not None:
             try:
-                if duration > 0:
-                    self.video_clip.fadeout(float(duration))
+                if isinstance(duration, int) or isinstance(duration, float):
+                    if 0 < duration <= 5:
+                        self.video_clip = self.video_clip.fadeout(float(duration))
             except:
                 pass
         return self
     
+    def audio_fadein(self, duration):
+        if self.video_clip is not None:
+            try:
+                if isinstance(duration, int) or isinstance(duration, float):
+                    if 0 < duration <= 5:
+                        self.video_clip = self.video_clip.audio_fadein(float(duration))
+            except:
+                pass
+        return self
+    
+    def audio_fadeout(self, duration):
+        if self.video_clip is not None:
+            try:
+                if isinstance(duration, int) or isinstance(duration, float):
+                    if 0 < duration <= 5:
+                        self.video_clip = self.video_clip.audio_fadeout(float(duration))
+            except:
+                pass
+        return self
+    
+    def set_contrast(self, luminosity=0, contrast=0):
+        if self.video_clip is not None:
+            try:
+                if isinstance(luminosity, int) and isinstance(contrast, int):
+                    if 0 < abs(duration) <= 100:
+                        self.video_clip = self.video_clip.fx(vfx.lum_contrast, lum=luminosity, contrast=contrast, contrast_thr=100)
+            except Exception as e:
+                print(e)
+                pass
+        return self
+    
     def render(self, index=-1):
         if self.video_clip is not None:
             try:
